@@ -58,7 +58,7 @@ irradiance <-
       return(NA_real_)
     }
     # if the waveband is undefined then use all data
-    if (is.null(w.band)){
+    if (length(w.band) == 0){
 #      w.band <- new_waveband(min(w.length), max(w.length))
       w.band <- new_waveband(min(w.length), max(w.length) + 1e-12)
       # we need to add a small number as the test is "<"
